@@ -2,19 +2,19 @@
 
 ;;; File: "gambit#.scm"
 
-;;; Copyright (c) 2005-2015 by Marc Feeley, All Rights Reserved.
+;;; Copyright (c) 2005-2022 by Marc Feeley, All Rights Reserved.
 
 ;;;============================================================================
 
 ;; Identifiers bound to syntactic forms and procedures defined by Gambit
 ;; are mapped to the empty namespace (no prefix).
 
-(##include "~~lib/r5rs#.scm") ;; most identifier bindings are inherited from R5RS
+(##include "r7rs#.scm") ;; most identifier bindings are inherited from R7RS
 
 (##namespace ("" ;; these identifier bindings are specific to Gambit
 
 ;; special forms
-define-record-type
+define-module-alias
 define-structure
 define-type
 define-type-of-thread
@@ -25,16 +25,17 @@ c-lambda
 c-define
 define-macro
 future
-include
+import
 declare
 namespace
 this-source-file
-parameterize
 receive
 time
-cond-expand
 define-cond-expand-feature
-letrec*
+define-values
+r7rs-guard
+syntax
+syntax-case
 
 ;; global variable
 default-random-source
@@ -51,27 +52,28 @@ address-info?
 address-infos
 all-bits-set?
 any-bits-set?
-append-f32vectors
-append-f64vectors
-append-s16vectors
-append-s32vectors
-append-s64vectors
-append-s8vectors
-append-strings
-append-u16vectors
-append-u32vectors
-append-u64vectors
-append-u8vectors
-append-vectors
+append-reverse
+append-reverse!
+apropos
 arithmetic-shift
 asinh
 atanh
 bit-count
 bit-set?
+bits
+bits->list
+bits->vector
 bitwise-and
+bitwise-andc1
+bitwise-andc2
+bitwise-eqv
 bitwise-ior
 bitwise-merge
+bitwise-nand
+bitwise-nor
 bitwise-not
+bitwise-orc1
+bitwise-orc2
 bitwise-xor
 box
 box?
@@ -85,16 +87,22 @@ call-with-output-string
 call-with-output-u8vector
 call-with-output-vector
 call/cc
+car+cdr
 cfun-conversion-exception-arguments
 cfun-conversion-exception-code
 cfun-conversion-exception-message
 cfun-conversion-exception-procedure
 cfun-conversion-exception?
+circular-list
+circular-list?
 clear-bit-field
-close-port
-command-line
+command-args
+command-name
+compilation-target
 compile-file
 compile-file-to-target
+concatenate
+concatenate!
 condition-variable-broadcast!
 condition-variable-name
 condition-variable-signal!
@@ -103,6 +111,7 @@ condition-variable-specific-set!
 condition-variable?
 configure-command-string
 conjugate
+cons*
 console-port
 continuation-capture
 continuation-graft
@@ -116,21 +125,25 @@ create-directory
 create-fifo
 create-link
 create-symbolic-link
+create-temporary-directory
 current-directory
-current-error-port
 current-exception-handler
+current-processor
 current-readtable
 current-thread
 current-time
 current-user-interrupt-handler
+datum->syntax
 datum-parsing-exception-kind
 datum-parsing-exception-parameters
 datum-parsing-exception-readenv
 datum-parsing-exception?
+dead-end
 deadlock-exception?
+default-user-interrupt-handler
 defer-user-interrupts
 delete-directory
-delete-file
+delete-file-or-directory
 directory-files
 display-continuation-backtrace
 display-continuation-dynamic-environment
@@ -143,6 +156,9 @@ display-procedure-environment
 divide-by-zero-exception-arguments
 divide-by-zero-exception-procedure
 divide-by-zero-exception?
+dotted-list?
+drop
+eighth
 eq?-hash
 equal?-hash
 eqv?-hash
@@ -151,7 +167,7 @@ error
 error-exception-message
 error-exception-parameters
 error-exception?
-exit
+executable-path
 expression-parsing-exception-kind
 expression-parsing-exception-parameters
 expression-parsing-exception-source
@@ -160,27 +176,36 @@ extract-bit-field
 f32vector
 f32vector->list
 f32vector-append
+f32vector-concatenate
 f32vector-copy
+f32vector-copy!
 f32vector-fill!
 f32vector-length
 f32vector-ref
+f32vector-set
 f32vector-set!
 f32vector-shrink!
 f32vector?
 f64vector
 f64vector->list
 f64vector-append
+f64vector-concatenate
 f64vector-copy
+f64vector-copy!
 f64vector-fill!
 f64vector-length
 f64vector-ref
+f64vector-set
 f64vector-set!
 f64vector-shrink!
 f64vector?
+fifth
 file-attributes
 file-creation-time
 file-device
-file-exists?
+file-exists-exception-arguments
+file-exists-exception-procedure
+file-exists-exception?
 file-group
 file-info
 file-info-attributes
@@ -207,8 +232,9 @@ file-number-of-links
 file-owner
 file-size
 file-type
-finite?
-first-bit-set
+filter
+first
+first-set-bit
 fixnum->flonum
 fixnum-overflow-exception-arguments
 fixnum-overflow-exception-procedure
@@ -216,6 +242,7 @@ fixnum-overflow-exception?
 fixnum?
 fl*
 fl+
+fl+*
 fl-
 fl/
 fl<
@@ -240,6 +267,7 @@ flexpm1
 flexpt
 flfinite?
 flfloor
+flhypot
 flilogb
 flinfinite?
 flinteger?
@@ -263,12 +291,15 @@ fltan
 fltanh
 fltruncate
 flzero?
+fold
+fold-right
 force-output
 foreign-address
 foreign-release!
 foreign-released?
 foreign-tags
 foreign?
+fourth
 fx*
 fx+
 fx-
@@ -279,22 +310,29 @@ fx>
 fx>=
 fxabs
 fxand
+fxandc1
+fxandc2
 fxarithmetic-shift
 fxarithmetic-shift-left
 fxarithmetic-shift-right
 fxbit-count
 fxbit-set?
+fxeqv
 fxeven?
-fxfirst-bit-set
+fxfirst-set-bit
 fxif
 fxior
 fxlength
 fxmax
 fxmin
 fxmodulo
+fxnand
 fxnegative?
+fxnor
 fxnot
 fxodd?
+fxorc1
+fxorc2
 fxpositive?
 fxquotient
 fxremainder
@@ -313,7 +351,6 @@ fxzero?
 gc-report-set!
 generate-proper-tail-calls
 gensym
-get-output-string
 get-output-u8vector
 get-output-vector
 getenv
@@ -331,14 +368,11 @@ host-info-aliases
 host-info-name
 host-info?
 host-name
-improper-length-list-exception-arg-num
-improper-length-list-exception-arguments
-improper-length-list-exception-procedure
-improper-length-list-exception?
+identity
 inactive-thread-exception-arguments
 inactive-thread-exception-procedure
 inactive-thread-exception?
-infinite?
+initial-current-directory
 initialized-thread-exception-arguments
 initialized-thread-exception-procedure
 initialized-thread-exception?
@@ -357,6 +391,10 @@ integer-sqrt
 invalid-hash-number-exception-arguments
 invalid-hash-number-exception-procedure
 invalid-hash-number-exception?
+invalid-utf8-encoding-exception-arguments
+invalid-utf8-encoding-exception-procedure
+invalid-utf8-encoding-exception?
+iota
 join-timeout-exception-arguments
 join-timeout-exception-procedure
 join-timeout-exception?
@@ -366,8 +404,16 @@ keyword-expected-exception-procedure
 keyword-expected-exception?
 keyword-hash
 keyword?
+last
+last-pair
+length+
+length-mismatch-exception-arg-id
+length-mismatch-exception-arguments
+length-mismatch-exception-procedure
+length-mismatch-exception?
 link-flat
 link-incremental
+list->bits
 list->f32vector
 list->f64vector
 list->s16vector
@@ -379,6 +425,11 @@ list->u16vector
 list->u32vector
 list->u64vector
 list->u8vector
+list-set
+list-sort
+list-sort!
+list-tabulate
+list=
 mailbox-receive-timeout-exception-arguments
 mailbox-receive-timeout-exception-procedure
 mailbox-receive-timeout-exception?
@@ -387,7 +438,6 @@ make-condition-variable
 make-f32vector
 make-f64vector
 make-mutex
-make-parameter
 make-random-source
 make-root-thread
 make-s16vector
@@ -406,6 +456,10 @@ make-will
 module-not-found-exception-arguments
 module-not-found-exception-procedure
 module-not-found-exception?
+module-search-order-add!
+module-search-order-reset!
+module-whitelist-add!
+module-whitelist-reset!
 multiple-c-return-exception?
 mutex-lock!
 mutex-name
@@ -414,12 +468,12 @@ mutex-specific-set!
 mutex-state
 mutex-unlock!
 mutex?
-nan?
 network-info
 network-info-aliases
 network-info-name
 network-info-number
 network-info?
+ninth
 no-such-file-or-directory-exception-arguments
 no-such-file-or-directory-exception-procedure
 no-such-file-or-directory-exception?
@@ -433,6 +487,11 @@ nonprocedure-operator-exception-code
 nonprocedure-operator-exception-operator
 nonprocedure-operator-exception-rte
 nonprocedure-operator-exception?
+not-in-compilation-context-exception-arguments
+not-in-compilation-context-exception-procedure
+not-in-compilation-context-exception?
+not-pair?
+null-list?
 number-of-arguments-limit-exception-arguments
 number-of-arguments-limit-exception-procedure
 number-of-arguments-limit-exception?
@@ -444,11 +503,10 @@ open-dummy
 open-event-queue
 open-file
 open-input-process
-open-input-string
 open-input-u8vector
 open-input-vector
+open-output-bytevector
 open-output-process
-open-output-string
 open-output-u8vector
 open-output-vector
 open-process
@@ -458,6 +516,7 @@ open-tcp-client
 open-tcp-server
 open-u8vector
 open-u8vector-pipe
+open-udp
 open-vector
 open-vector-pipe
 os-exception-arguments
@@ -482,9 +541,12 @@ path-strip-extension
 path-strip-trailing-directory-separator
 path-strip-volume
 path-volume
-port-settings-set!
+permission-denied-exception-arguments
+permission-denied-exception-procedure
+permission-denied-exception?
+poll-point
 port-io-exception-handler-set!
-port?
+port-settings-set!
 pp
 pretty-print
 primordial-exception-handler
@@ -493,6 +555,9 @@ println
 process-pid
 process-status
 process-times
+processor-id
+processor?
+proper-list?
 protocol-info
 protocol-info-aliases
 protocol-info-name
@@ -512,15 +577,16 @@ random-source-state-ref
 random-source-state-set!
 random-source?
 random-u8vector
-range-exception-arg-num
+range-exception-arg-id
 range-exception-arguments
 range-exception-procedure
 range-exception?
 read-all
-read-line
+read-file-string
+read-file-string-list
+read-file-u8vector
 read-substring
 read-subu8vector
-read-u8
 readtable-case-conversion?
 readtable-case-conversion?-set
 readtable-comment-handler
@@ -545,13 +611,17 @@ readtable-write-extended-read-macros?
 readtable-write-extended-read-macros?-set
 readtable?
 real-time
+remove
+remq
 rename-file
 repl-display-environment?
+repl-error-port
 repl-input-port
 repl-output-port
 repl-result-history-max-length-set!
 repl-result-history-ref
 replace-bit-field
+reverse!
 rpc-remote-error-exception-arguments
 rpc-remote-error-exception-message
 rpc-remote-error-exception-procedure
@@ -559,45 +629,60 @@ rpc-remote-error-exception?
 s16vector
 s16vector->list
 s16vector-append
+s16vector-concatenate
 s16vector-copy
+s16vector-copy!
 s16vector-fill!
 s16vector-length
 s16vector-ref
+s16vector-set
 s16vector-set!
 s16vector-shrink!
 s16vector?
 s32vector
 s32vector->list
 s32vector-append
+s32vector-concatenate
 s32vector-copy
+s32vector-copy!
 s32vector-fill!
 s32vector-length
 s32vector-ref
+s32vector-set
 s32vector-set!
 s32vector-shrink!
 s32vector?
 s64vector
 s64vector->list
 s64vector-append
+s64vector-concatenate
 s64vector-copy
+s64vector-copy!
 s64vector-fill!
 s64vector-length
 s64vector-ref
+s64vector-set
 s64vector-set!
 s64vector-shrink!
 s64vector?
 s8vector
 s8vector->list
 s8vector-append
+s8vector-concatenate
 s8vector-copy
+s8vector-copy!
 s8vector-fill!
 s8vector-length
 s8vector-ref
+s8vector-set
 s8vector-set!
 s8vector-shrink!
 s8vector?
 scheduler-exception-reason
 scheduler-exception?
+script-directory
+script-file
+second
 seconds->time
 serial-number->object
 service-info
@@ -608,6 +693,7 @@ service-info-protocol
 service-info?
 set-box!
 setenv
+seventh
 sfun-conversion-exception-arguments
 sfun-conversion-exception-code
 sfun-conversion-exception-message
@@ -618,12 +704,15 @@ sinh
 six.!
 six.!x
 six.&x
+six.**x
 six.*x
 six.++x
 six.+x
 six.--x
 six.-x
 six.arrow
+six.asyncx
+six.awaitx
 six.break
 six.call
 six.case
@@ -636,37 +725,46 @@ six.define-variable
 six.do-while
 six.dot
 six.for
+six.from-import
+six.from-import-*
 six.goto
 six.identifier
 six.if
+six.import
 six.index
+six.infix
 six.label
 six.list
 six.literal
 six.make-array
 six.new
+six.notx
 six.null
-six.prefix
 six.procedure
 six.procedure-body
 six.return
 six.switch
+six.typeofx
 six.while
+six.x!==y
 six.x!=y
 six.x%=y
 six.x%y
 six.x&&y
 six.x&=y
 six.x&y
+six.x**=y
+six.x**y
 six.x*=y
 six.x*y
 six.x++
 six.x+=y
 six.x+y
-|six.x,y|
 six.x--
 six.x-=y
 six.x-y
+six.x//=y
+six.x//y
 six.x/=y
 six.x/y
 six.x:-y
@@ -676,24 +774,36 @@ six.x<<=y
 six.x<<y
 six.x<=y
 six.x<y
+six.x===y
 six.x==y
 six.x=y
 six.x>=y
 six.x>>=y
+six.x>>>=y
+six.x>>>y
 six.x>>y
 six.x>y
 six.x?y:z
+six.x@=y
+six.x@y
 six.x^=y
 six.x^y
-|six.x\|=y|
-|six.x\|y|
-|six.x\|\|y|
+six.xandy
+six.xinstanceofy
+six.xiny
+six.xisy
+six.xory
+six.yieldx
 six.~x
+|six.x,y|
+|six.x\|=y|
+|six.x\|\|y|
+|six.x\|y|
+sixth
 socket-info-address
 socket-info-family
 socket-info-port-number
 socket-info?
-square
 stack-overflow-exception?
 started-thread-exception-arguments
 started-thread-exception-procedure
@@ -704,6 +814,8 @@ string->keyword
 string->uninterned-keyword
 string->uninterned-symbol
 string-ci=?-hash
+string-concatenate
+string-set
 string-shrink!
 string=?-hash
 subf32vector
@@ -742,6 +854,9 @@ subvector
 subvector-fill!
 subvector-move!
 symbol-hash
+syntax->datum
+syntax->list
+syntax->vector
 system-stamp
 system-type
 system-type-string
@@ -757,16 +872,21 @@ table-ref
 table-search
 table-set!
 table?
+take
 tanh
+tcp-client-local-socket-info
 tcp-client-peer-socket-info
 tcp-client-self-socket-info
 tcp-server-socket-info
 tcp-service-register!
 tcp-service-unregister!
+tenth
 terminated-thread-exception-arguments
 terminated-thread-exception-procedure
 terminated-thread-exception?
 test-bit-field?
+third
+thread
 thread-base-priority
 thread-base-priority-set!
 thread-group->thread-group-list
@@ -776,6 +896,8 @@ thread-group->thread-vector
 thread-group-name
 thread-group-parent
 thread-group-resume!
+thread-group-specific
+thread-group-specific-set!
 thread-group-suspend!
 thread-group-terminate!
 thread-group?
@@ -800,13 +922,15 @@ thread-start!
 thread-state
 thread-state-abnormally-terminated-reason
 thread-state-abnormally-terminated?
-thread-state-active-timeout
-thread-state-active-waiting-for
-thread-state-active?
 thread-state-initialized?
 thread-state-normally-terminated-result
 thread-state-normally-terminated?
+thread-state-running-processor
+thread-state-running?
 thread-state-uninitialized?
+thread-state-waiting-for
+thread-state-waiting-timeout
+thread-state-waiting?
 thread-suspend!
 thread-terminate!
 thread-thread-group
@@ -826,7 +950,7 @@ tty-paren-balance-duration-set!
 tty-text-attributes-set!
 tty-type-set!
 tty?
-type-exception-arg-num
+type-exception-arg-id
 type-exception-arguments
 type-exception-procedure
 type-exception-type-id
@@ -834,30 +958,39 @@ type-exception?
 u16vector
 u16vector->list
 u16vector-append
+u16vector-concatenate
 u16vector-copy
+u16vector-copy!
 u16vector-fill!
 u16vector-length
 u16vector-ref
+u16vector-set
 u16vector-set!
 u16vector-shrink!
 u16vector?
 u32vector
 u32vector->list
 u32vector-append
+u32vector-concatenate
 u32vector-copy
+u32vector-copy!
 u32vector-fill!
 u32vector-length
 u32vector-ref
+u32vector-set
 u32vector-set!
 u32vector-shrink!
 u32vector?
 u64vector
 u64vector->list
 u64vector-append
+u64vector-concatenate
 u64vector-copy
+u64vector-copy!
 u64vector-fill!
 u64vector-length
 u64vector-ref
+u64vector-set
 u64vector-set!
 u64vector-shrink!
 u64vector?
@@ -865,26 +998,36 @@ u8vector
 u8vector->list
 u8vector->object
 u8vector-append
+u8vector-concatenate
 u8vector-copy
+u8vector-copy!
 u8vector-fill!
 u8vector-length
 u8vector-ref
+u8vector-set
 u8vector-set!
 u8vector-shrink!
 u8vector?
+udp-destination-set!
+udp-local-socket-info
+udp-read-subu8vector
+udp-read-u8vector
+udp-source-socket-info
+udp-write-subu8vector
+udp-write-u8vector
 unbound-global-exception-code
 unbound-global-exception-rte
 unbound-global-exception-variable
 unbound-global-exception?
+unbound-key-exception-arguments
+unbound-key-exception-procedure
+unbound-key-exception?
 unbound-os-environment-variable-exception-arguments
 unbound-os-environment-variable-exception-procedure
 unbound-os-environment-variable-exception?
 unbound-serial-number-exception-arguments
 unbound-serial-number-exception-procedure
 unbound-serial-number-exception?
-unbound-table-key-exception-arguments
-unbound-table-key-exception-procedure
-unbound-table-key-exception?
 unbox
 unbreak
 uncaught-exception-arguments
@@ -911,8 +1054,11 @@ user-info-shell
 user-info-uid
 user-info?
 user-name
-vector-append
-vector-copy
+vector->bits
+vector-cas!
+vector-concatenate
+vector-inc!
+vector-set
 vector-shrink!
 void
 will-execute!
@@ -930,12 +1076,20 @@ with-output-to-process
 with-output-to-string
 with-output-to-u8vector
 with-output-to-vector
+write-file-string
+write-file-string-list
+write-file-u8vector
 write-substring
 write-subu8vector
-write-u8
 wrong-number-of-arguments-exception-arguments
 wrong-number-of-arguments-exception-procedure
 wrong-number-of-arguments-exception?
+wrong-number-of-values-exception-code
+wrong-number-of-values-exception-rte
+wrong-number-of-values-exception-vals
+wrong-number-of-values-exception?
+wrong-processor-c-return-exception?
+xcons
 
 ))
 
